@@ -10,4 +10,4 @@ class DeviceScannerConfig(PluginConfig):
     base_url = 'device-scan',
     required_settings = []
 
-config = MacScannerConfig
\ No newline at end of file
+config = DeviceScannerConfig
\ No newline at end of file
