@@ -1,10 +1,9 @@
 from setuptools import find_packages, setup
 
 setup(
-    name='netbox-mac-scan',
-    version='0.1',
-    description='A Netbox plugin for MAC address scanning',
-    url='https://github.com/seanmcollins/netbox-mac-scan',
+    name='netbox-plugin-test',
+    version='0.2',
+    description='A Netbox plugin test',
     author='Sean Collins',
     install_requires=[],
     packages=find_packages(),
